@@ -7,6 +7,11 @@ class IndicoRequestError(IndicoError):
         super().__init__(f"Status: {code}, Error: {error}\n\tExtras: {extras}")
 
 
+class IndicoTimeoutError(IndicoError):
+    def __init__(self, duration):
+        super().__init__(f"Request timed out after {duration:0.3f} seconds.")
+
+
 class IndicoDecodingError(IndicoError):
     def __init__(self, mime, charset, content):
         super().__init__(f"Failed to decode with {mime}:{charset}. Content {content}")
@@ -27,4 +32,4 @@ class IndicoNotFound(IndicoError):
 
 class IndicoAuthenticationFailed(IndicoError):
     def __init__(self):
-        super().__init__("Failed to authenticate")
\ No newline at end of file
+        super().__init__("Failed to authenticate")
