@@ -1,7 +1,7 @@
 from typing import List
 
 from indico.client.request import GraphQLRequest, RequestChain
-from indico.errors import IndicoError
+from indico.errors import IndicoError, IndicoInputError
 from indico.queries.storage import UploadDocument
 from indico.types import Job, Submission, Workflow
 
@@ -66,19 +66,19 @@ class GetWorkflow(ListWorkflows):
 class _WorkflowSubmission(GraphQLRequest):
 
     query = """
-        mutation workflowSubmissionMutation($workflowId: Int!, $files: [FileInput]!, $recordSubmission: Boolean) {
-            workflowSubmission(workflowId: $workflowId, files: $files, recordSubmission: $recordSubmission) {
+        mutation workflowSubmissionMutation($workflowId: Int!, ${arg_}: {type_}, $recordSubmission: Boolean) {{
+            {mutation_name}(workflowId: $workflowId, {arg_}: ${arg_}, recordSubmission: $recordSubmission) {{
                 jobIds
                 submissionIds
-            }
-        }
+            }}
+        }}
     """
 
     detailed_query = """
-        mutation workflowSubmissionMutation($workflowId: Int!, $files: [FileInput]!, $recordSubmission: Boolean) {
-            workflowSubmission(workflowId: $workflowId, files: $files, recordSubmission: $recordSubmission) {
+        mutation workflowSubmissionMutation($workflowId: Int!, ${arg_}: {type_}, $recordSubmission: Boolean) {{
+            {mutation_name}(workflowId: $workflowId, {arg_}: ${arg_}, recordSubmission: $recordSubmission) {{
                 submissionIds
-                submissions {
+                submissions {{
                     id
                     datasetId
                     workflowId
@@ -88,31 +88,39 @@ class _WorkflowSubmission(GraphQLRequest):
                     resultFile
                     retrieved
                     errors
-                }
-            }
-        }
+                }}
+            }}
+        }}
     """
 
+    query_format = {"arg_": "files", "type_": "[FileInput]!"}
+    mutation_name = "workflowSubmission"
+
     def __init__(
         self,
         workflow_id: int,
-        files: List[str],
         submission: bool,
+        files: List[str] = None,
+        urls: List[str] = None,
         detailed_response: bool = False,
     ):
         self.workflow_id = workflow_id
         self.record_submission = submission
+
+        q = self.detailed_query if detailed_response else self.query
+
         super().__init__(
-            query=self.detailed_query if detailed_response else self.query,
+            query=q.format(mutation_name=self.mutation_name, **self.query_format),
             variables={
                 "files": files,
+                "urls": urls,
                 "workflowId": workflow_id,
                 "recordSubmission": submission,
             },
         )
 
     def process_response(self, response):
-        response = super().process_response(response)["workflowSubmission"]
+        response = super().process_response(response)[self.mutation_name]
         if "submissions" in response:
             return [Submission(**s) for s in response["submissions"]]
         elif self.record_submission:
@@ -122,13 +130,21 @@ class _WorkflowSubmission(GraphQLRequest):
         return [Job(id=job_id) for job_id in response["jobIds"]]
 
 
+class _WorkflowUrlSubmission(_WorkflowSubmission):
+    query_format = {"arg_": "urls", "type_": "[String]!"}
+    mutation_name = "workflowUrlSubmission"
+
+
+
 class WorkflowSubmission(RequestChain):
     """
-    Submit files to a workflow for processing
+    Submit files to a workflow for processing.
+    One of `files` or `urls` is required.
 
     Args:
         workflow_id (int): Id of workflow to submit files to
-        files (List[str]): List of local file paths to submit
+        files (List[str], optional): List of local file paths to submit
+        urls (List[str], optional): List of urls to submit
         submission (bool, optional): Process these files as normal submissions.
             Defaults to True.
             If False, files will be processed as AsyncJobs, ignoring any workflow
@@ -139,43 +155,60 @@ class WorkflowSubmission(RequestChain):
             Otherwise, they will be AsyncJob ids.
 
     """
+    detailed_response = False
 
-    def __init__(self, workflow_id: int, files: List[str], submission: bool = True):
+    def __init__(
+        self,
+        workflow_id: int,
+        files: List[str] = None,
+        urls: List[str] = None,
+        submission: bool = True,
+    ):
         self.workflow_id = workflow_id
         self.files = files
+        self.urls = urls
         self.submission = submission
+        if not self.files and not self.urls:
+            raise IndicoInputError("One of 'files' or 'urls' must be specified")
+        elif self.files and self.urls:
+            raise IndicoInputError("Only one of 'files' or 'urls' must be specified")
 
     def requests(self):
-        yield UploadDocument(files=self.files)
-        yield _WorkflowSubmission(
-            files=self.previous,
-            workflow_id=self.workflow_id,
-            submission=self.submission,
-        )
+        if self.files:
+            yield UploadDocument(files=self.files)
+            yield _WorkflowSubmission(
+                workflow_id=self.workflow_id,
+                files=self.previous,
+                submission=self.submission,
+                detailed_response=self.detailed_response,
+            )
+        elif self.urls:
+            yield _WorkflowUrlSubmission(
+                workflow_id=self.workflow_id,
+                urls=self.urls,
+                submission=self.submission,
+                detailed_response=self.detailed_response,
+            )
 
 
-class WorkflowSubmissionDetailed(RequestChain):
+class WorkflowSubmissionDetailed(WorkflowSubmission):
     """
-    Submit files to a workflow for processing as normal submissions
+    Submit files to a workflow for processing.
+    One of `files` or `urls` is required.
+    Submission recording is mandatory.
 
     Args:
         workflow_id (int): Id of workflow to submit files to
-        files (List[str]): List of local file paths to submit
+        files (List[str], optional): List of local file paths to submit
+        urls (List[str], optional): List of urls to submit
 
     Returns:
         List[Submission]: Submission objects created
 
     """
+    detailed_response = True
 
-    def __init__(self, workflow_id: int, files: List[str]):
-        self.workflow_id = workflow_id
-        self.files = files
-
-    def requests(self):
-        yield UploadDocument(files=self.files)
-        yield _WorkflowSubmission(
-            files=self.previous,
-            workflow_id=self.workflow_id,
-            submission=True,
-            detailed_response=True,
-        )
+    def __init__(
+        self, workflow_id: int, files: List[str] = None, urls: List[str] = None
+    ):
+        super().__init__(workflow_id, files=files, urls=urls, submission=True)
